@@ -1,16 +1,23 @@
-mcPrt<-function(asset,sub="::",pstvRtn=FALSE,L=1, Rf=0.0){
+mcPrt<-function(asset,sub="::",pstvRtn=FALSE, pr="daily", Rf=0.0){
   z<-list()
 #  graphics.off()
   mRetn<-SD<-Sharp<-array(0)
   asset<-asset[!duplicated(asset)]
   if(length(asset)>1){
     m.close<-get(asset[1])$Close[sub]
-    m.return <-(diff(log(m.close),lag=L))
+    #m.return <-(diff(log(m.close),lag=L))
+    ifelse(pr=="daily", m.return <-dailyReturn(m.close),ifelse(pr=="weekly", m.return <-weeklyReturn(m.close), 
+                                                               ifelse(pr=="monthly", m.return <-monthlyReturn(m.close))))
+    
     m.max<-get(asset[1])$High[sub]
     m.min<-get(asset[1])$Low[sub]
   for(i in 2:length(asset)){
       tem.m.close<-get(asset[i])$Close[sub]
-      tem.m.return <-(diff(log(tem.m.close),lag=L))
+    #  tem.m.return <-(diff(log(tem.m.close),lag=L))
+      ifelse(pr=="daily", tem.m.return <-dailyReturn(tem.m.close),ifelse(pr=="weekly", tem.m.return <-weeklyReturn(tem.m.close),
+                                                                     ifelse(pr=="monthly", tem.m.return <-monthlyReturn(tem.m.close))))
+      
+      
       m.close<-merge(m.close,tem.m.close)
       m.return<-merge(m.return,tem.m.return)
       tem.m.max<-get(asset[i])$High[sub]
@@ -21,7 +28,9 @@ mcPrt<-function(asset,sub="::",pstvRtn=FALSE,L=1, Rf=0.0){
   }
   else {
     m.close<-get(asset[1])$Close[sub]
-    m.return <-(diff(log(m.close),lag=L))
+    ifelse(pr=="daily", m.return <-dailyReturn(m.close), ifelse(pr=="weekly", m.return <-weeklyReturn(m.close),
+                                                                ifelse(pr=="monthly", m.return <-monthlyReturn(m.close))))
+    #m.return <-(diff(log(m.close),lag=L))
     m.max<-get(asset[1])$High[sub]
     m.min<-get(asset[1])$Low[sub]
   }
@@ -55,7 +64,7 @@ if(length(asset)>1){
   z$out<-data.frame(mRetn,SD,Sharp)
   row.names(z$out)<-asset
   colnames(z$out)<-c("meanReturn","volatility","sharpRatio" )
-  cat("Values in % base lag=",L,":\n")
+  cat("Values in % base ",pr,":\n")
 print(round(z$out*100,2))
 cat("\n")
   if(length(asset)>1){
